# Common Form Snippets

These forms are not valid XLSForms by themselves.

Instead they contain fields to be used to concatenate and create forms
that are used for a standardised mapping workflow.

- `mandatory_fields.xls` contains mandatory fields for FMTM such as
  the feature and task id selections.
- `digitisation_fields.xls` contains fields for validating the digitisation,
  i.e. if the building exists or is lumped / split during mapping.
